/**
 * PMLib - PMLEventHandler example
 *
 * This example demonstrates automatic event handling, by attaching a 
 * PMLEventHandler object to a PMLSequencer. Similar to matrix integration
 * this simplifies the data mapping process in more complex applications.
 */

import pmlib.*;

private PMLSequencer sequencer;
private color colour;

void setup(){
  size(400, 400);
  background(0);

  // Create the event handler and add a method with the /colour tag  
  PMLEventHandler handler = new PMLEventHandler();
  handler.add("/colour", this, "setBackgroundColour", new char[] { 'i', 'i', 'i' });

  // Create the sequener
  sequencer = new PMLSequencer();
  sequencer.setVerbose(true);  
  
  // Attach the event handler
  sequencer.setEventHandler(handler);
  
  // Load and play the sequence
  sequencer.read(sketchPath("example.seq"));
  sequencer.play();
  
  // Initialise the colour variable    
  colour = color(0);
}

void draw(){
  // Sequencer events are automatically routed to the handler when frame() is called
  sequencer.frame();
  
  // Set the backround colour
  background(colour);
  
}

// Define a method to which sequencer events may be routed
public void setBackgroundColour(int r, int g, int b){
  colour = color(r, g, b);
}
