/**
 * PMLib - PMLEventHandler example
 *
 * This example demonstrates value routing using the PMLEventHandler
 * object. Matrix values are gathered manually and routed to the 
 * setPositionX and setPositionY methods using the created event
 * handler. The resultant values are represented by the ellipse location.
 *
 * In reality, it would prove simpler to simply access the matrix
 * values using the get() method. For more complex solutions,
 * however, the PMLEventHandler object can greatly simplify the
 * required code.
 *
 * The matrix setEventHandler() method simplifies much of this code as
 * demonstrated in the MatrixEventHandlerAuto example.
 */

import pmlib.*;

private PMLMatrix matrix;
private PMLEventHandler handler;
private int x, y;

void setup(){
  size(400, 400);
  frameRate(50);
  smooth();
  background(0);
  
  // Create the matrix and assign an input and output channel
  matrix = new PMLMatrix();
  matrix.addInput("/frame", 0f, 100f);
  matrix.addOutput("/frame", "/x", 0f, 400f);
  matrix.addOutput("/frame", "/y", 400f, 0f);
  
  // Create the event handler and add the methods
  handler = new PMLEventHandler();
  handler.add("/x", this, "setPositionX", new char[] { 'i' });
  handler.add("/y", this, "setPositionY", new char[] { 'i' });  
}

void draw(){
  background(0);
  
  // Route the current frame throught the matrix
  PMLFloat frame = new PMLFloat("/frame", frameCount % 100);
  matrix.route(frame);
  
  // Gather matrix outputs
  PMLFloat[] outputs = matrix.getAll();
  
  // Route the matrix outputs through the event handler
  handler.route(outputs);
  
  // Draw the ellipse
  noStroke();
  fill(255);
  ellipse(x, y, 20, 20);
}

// Define the methods to which matrix values will be routed
public void setPositionX(int _x){
  x = _x;  
}
public void setPositionY(int _y){
  y = _y;
}


