// PMLib OSC example

import pmlib.*;
import oscP5.*;
import netP5.*;

private OscP5 osc;
private NetAddress net;
private PMLMatrix matrix;
private PMLFloat[] output;
private int interval, icount;

void setup(){
  size(400, 400);
  frameRate(50);
  background(0);
  
  osc = new OscP5(this, 3001);
  net = new NetAddress("127.0.0.1", 3002);
  interval = 0;
  
  // Create a new matrix
  matrix = new PMLMatrix();    

  // Create volume input channel and attach two outputs  
  matrix.addInput("/pml.in_vol", height, 0.0);
  matrix.addOutput("/pml.in_vol", "/pml.out_vol");
  matrix.addOutput("/pml.in_vol", "/pml.out_vmidi", 0.0, 127.0);
  
  // Create pan input channel and attach output
  matrix.addInput("/pml.in_pan", 0.0, width);
  matrix.addOutput("/pml.in_pan", "/pml.out_pan", -1.0, 1.0);
  
  // Store references to all matrix outputs
  output = matrix.getAll();
}

void draw(){
  background(0);
  noFill();
  stroke(255, 150);
  line(width * 0.5, 0.0, width * 0.5, height);
  line(0.0, height * 0.5, width, height * 0.5);
  
  interval ++;
  if(interval == 5){
    // Route mouse values to each matrix input channel
    matrix.route("/pml.in_vol", mouseY);
    matrix.route("/pml.in_pan", mouseX);
    
    // Send all matrix outputs - the matrix preserves references,
    // so the array does not need to be updated
    oscSend(output); 
    interval = 0;    
  }
}

// Convert PMLFloat values into OscMessage objects and send
private void oscSend(PMLFloat[] fa){
  for(int i = 0; i < fa.length; i ++){
    OscMessage msg = new OscMessage(fa[i].tag());
    msg.add(fa[i].floatValue());
    osc.send(msg, net);
  }  
}
