import pmlib.*;

/**
 * PMLib - PMLSequencer example
 *
 * Within this example, mouse clicks generate a PMLEvent object which is
 * stored within the sequencer while recording. On playback, the sequencer
 * output is rendered as a series of points matching the input.
 *
 * Usage: Press 'r' to initiate recording and then click the mouse in different
 * locations. Press 'r' again to stop recording and save the sequence. Press
 * 'p' to play back the stored sequence.
 */
 
PMLSequencer sequencer;

void setup() {
  size(400, 400);
  background(0);
  
  // Create the sequencer
  sequencer = new PMLSequencer();
  sequencer.setVerbose(true);  
}

void draw() {
  // Iterate the sequencer frame and gather any stored events
  PMLEvent[] events = sequencer.frame();
  
  // Render any stored points
  noStroke();
  fill(100, 0, 255, 150);
  for(PMLEvent event : events){
    // Use a conditional to ensure that the stored event matches the requirement
    if(event.hasTag("/point") && event.vars().length > 1)
      ellipse(event.vars()[0], event.vars()[1], 20, 20);
  }
}

void mouseReleased(){
  // Create a new event with the tag "/point" for the current location and store it
  PMLEvent event = sequencer.createEvent("/point", new float[] { mouseX, mouseY });
  sequencer.event(event);

  // Render the clicked location  
  noStroke();
  fill(255, 0, 100, 150);
  ellipse(mouseX, mouseY, 20, 20);
}

void keyReleased() {
  if(key == 'p' || key == 'P' && !sequencer.isRecording()) {
    if(!sequencer.isPlaying()) sequencer.read(sketchPath("example.seq"));   
    sequencer.play();
  }
  if(key == 'r' || key == 'R' && !sequencer.isPlaying()) {
    if(sequencer.isRecording()) sequencer.write(sketchPath("example.seq"));
    else {
      background(0);
      sequencer.record();
    }
  }
}
