package pmlib;
import java.io.*;
/**
 * PMLTools Class
 * <p>The PMTools object provides a range of static utility functions.
 * <p>This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * <p>This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * <p>You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 * @author Stephen Callear
 */
public class PMLTools extends Object{
    /**
     * Converts an input text file to an array of strings
     * <p>If the input file cannot be parsed a null value will be returned.
     * @param f file
     * @return string array
     */
    public static String [] readStrings(String f){
        try {
            return readStrings(new File(f));
        }
        catch (NullPointerException e){
            System.err.println("Error: loadStrings NullPointerException");
            return null;
        }
    }
    /**
     * Converts an input text file to an array of strings
     * <p>If the input file cannot be parsed a null value will be returned.
     * @param f file
     * @return string array
     */
    public static String [] readStrings(File f){
        FileReader fr;
        String [] es = null;
        try {
            fr = new FileReader(f);
        }
        catch (FileNotFoundException e) {
            System.err.println("Error: loadStrings FileNotFoundException - " + f.getName());
            return es;
        }
        BufferedReader br = new BufferedReader(fr);
        int line_count = 0;
        while (true){
            String line;
            try {
                line = br.readLine();
            }
            catch (IOException e){
                System.err.println("Error: loadStrings IOException at readLine()");
                return es;
            }
            if (line != null)
                line_count ++;
            else
                break;
        }
        try {
            fr.close();
            br.close();
            fr = new FileReader(f);
            br = new BufferedReader(fr);
        }
        catch (IOException e){
            return es;
        }
        String [] rs = new String[line_count];
        for (int i = 0; i < rs.length; i ++){
            try {
                rs[i] = br.readLine();
            }
            catch (IOException e){
                return es;
            }
        }
        return rs;
    }
    /**
     * Write an array of strings to the specified file
     * @param sa string array
     * @param f output file
     * @return true if the file was successfully written
     */
    public static boolean writeStrings(String[] sa, String f){
        try {
            return writeStrings(sa, new File(f));
        }
        catch (NullPointerException e){
            System.err.println("Error: writeStrings NullPointerException");
            return false;
        }
    }
    /**
     * Write an array of strings to the specified file
     * @param sa string array
     * @param f output file
     * @return true if the file was successfully written
     */
    public static boolean writeStrings(String[] sa, File f){
        FileWriter fw;
        try {
            fw = new FileWriter(f);
            for(String s : sa)
                if(s != null) fw.write(s + "\n");
            fw.flush();
            fw.close();
            return true;
        }
        catch (IOException e){
            System.err.println("Error : writeStrings IOException.");
            return false;
        }
    }
    /**
     * Combine all the strings within the specified array and return the result
     * @param s array of strings
     * @return a single combined string
     */
    public static String combineStrings(String[] s){
        return combineStrings(s, null);
    }
    /**
     * Combine all the strings within the specified array with the specified spacer
     * string and return the result
     * @param sa array of strings
     * @param ss spacer string
     * @return a single combined string
     */
    public static String combineStrings(String[] sa, String ss){
        StringBuilder str_out = new StringBuilder();
        for(int i = 0; i < sa.length; i ++){
            str_out.append(sa[i]);
            if(ss != null && i < sa.length - 1)
                str_out.append(ss);
        }
        return str_out.toString();
    }
}
