import com.cycling74.max.*;
import pmlib.PMLSequencer;
import pmlib.PMLEvent;
/**
 * MSequencer Class
 * <p>The MSequencer object is a wrapper for the pmlib.PMLSequencer object for
 * use within Max/MSP.
 * <p>This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * <p>This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * <p>You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 * @author Stephen Callear
 */
public class MSequencer extends MaxObject {
    private PMLSequencer sequencer;
    public MSequencer(){
        sequencer = new PMLSequencer();
        declareInlets(new int[] { DataTypes.ALL });
        declareOutlets(new int[] { DataTypes.ALL, DataTypes.INT });
        setInletAssist(new String[] { "Control" });
        setOutletAssist(new String[] { "Event", "Frame" });
    }
    public MSequencer(String f){
        this();
        sequencer.read(f);

    }
    @Override public void bang(){
        frame();
    }
    public void event(Atom[] a){
        if(!sequencer.isRecording() || a.length < 1) return;
        if(!a[0].isString()) return;
        float[] v = new float[a.length - 1];
        for(int i = 0; i < v.length; i ++){
            v[i] = a[i + 1].toFloat();
        }
        sequencer.event(sequencer.createEvent(a[0].toString(), v));
    }
    public void read(String f){
        if(sequencer.read(f)) infoMessage("length", sequencer.getSequenceLength());
    }
    public void write(String f){
        sequencer.write(f);
    }
    public void play(){
        if(sequencer.sequenceLoaded()) {
            sequencer.play();
            infoMessage("active", 1);
        }
    }
    public void record(){
        sequencer.record();
        infoMessage("active", 1);
    }
    public void stop(){
        if(sequencer.isActive()){
            sequencer.stop();
            infoMessage("active", 0);
        }
    }
    public void length(){
        if(!sequencer.sequenceLoaded()) return;        
        infoMessage("length", sequencer.getSequenceLength());
    }
    private void frame(){
        PMLEvent[] e = sequencer.frame();
        for(int i = 0; i < e.length; i ++)
            outlet(0, eventToAtom(e[i]));
        outlet(1, Atom.newAtom(sequencer.getCurrentFrame()));
        if(sequencer.isPlaying() && sequencer.getCurrentFrame() >= sequencer.getSequenceLength())
            infoMessage("active", 0);
    }
    private Atom[] eventToAtom(PMLEvent e){
        float[] v = e.vars();
        Atom[] a = new Atom[v.length + 1];
        a[0] = Atom.newAtom(e.tag());
        for(int i = 0; i < v.length ; i ++)
            a[i + 1] = Atom.newAtom(v[i]);
        return a;
    }
    private void infoMessage(String s, int v){
        infoMessage(s, new int[] { v });
    }
    private void infoMessage(String s, int[] v){
        Atom[] a = new Atom[v.length + 1];
        a[0] = Atom.newAtom(s);
        for(int i = 0; i < v.length; i ++)
            a[i + 1] = Atom.newAtom(v[i]);
        int out = getInfoIdx();
        if(out != -1) outlet(out, a);
    }
}
