package pslib;
/**
 * BrownianForce Class
 * <p>The BrownianForce object extends the PSForce class allowing brownian motion
 * to be applied to a DynamicParticle object. Force magnitude is calculated based
 * on the specified minimum and maximum values, decay curve and decay mode.
 * <p>This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * <p>This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * <p>You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 * @author Stephen Callear
 */
public class BrownianForce extends PSForce {
    /**
     * Create a static object instance with the specified values
     * @param m magnitude
     */
    public BrownianForce(float m){
        super(m);        
    }
    /**
     * Create a dynamic object instance with the specified values
     * @param mi minimum magnitude
     * @param ma maximum magnitude
     * @param m decay mode
     * @param c decay curve exponent
     */
    public BrownianForce(float mi, float ma, int m, float c){
        super(mi, ma, m, c);
    }
    /**
     * Update the specified particle
     * @param p particle
     */
    public void update(DynamicParticle p){
        PSVector vel = p.getVelocity(); // Get the particle velocity vector assuming a copy
        PSVector vec = PSTools.randomVector(getMagnitude(p));
        vel.add(vec);
        p.setVelocity(vel); // Re-apply velocity vector assuming a copy

    }
}
