package pslib;
/**
 * LinearForce Class
 * <p>The LinearForce object extends the PSForce class allowing a linear force vector
 * to be applied to a DynamicParticle object. The force calculated based on the
 * specified minimum and maximum values, decay curve and decay mode.
 * <p>This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * <p>This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * <p>You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 * @author Stephen Callear
 */
public class LinearForce extends PSForce {
    private PSVector vector;
    public LinearForce(PSVector v, float m){
        this(v, m, m, STATIC, 1f);
    }
    /**
     * Create a new object instance with the specified values
     * @param v force vector
     * @param mi minimum magnitude
     * @param ma maximum magnitude
     * @param m decay mode
     * @param c decay curve exponent
     */
    public LinearForce(PSVector v, float mi, float ma, int m, float c){
        super(mi, ma, m, c);
        if(v != null) 
            vector = v;
        else
            vector = new PSVector(0.0f, 1.0f, 0.0f); // Use a default vector if none is specified
    }
    /**
     * Update the specified particle
     * @param p particle
     */
    public void update(DynamicParticle p){
        PSVector vel = p.getVelocity(); // Get the velocity vector assuming copy
        vel.add(PSVector.scale(vector, getMagnitude(p)));
        p.setVelocity(vel); // Re-apply vector assuming copy
    }
}
