package pslib;

/**
 * PSConstants Interface
 * <p>The PSConstants interface specifies contains all the commonly used variables
 * within the library.
 ** <p>This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * <p>This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * <p>You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 * @author Stephen Callear
 */
public interface PSConstants {
    /**
     * None envelope type
     */
    public static int NONE = 0;
    /**
     * Static envelope type
     */
    public static int STATIC = 1;
    /**
     * Linear envelope type
     */
    public static int LINEAR = 2;
    /**
     * Inverse envelope type
     */
    public static int INVERSE = 3;
    /**
     * Triangular envelope type
     */
    public static int TRIANGULAR = 4;
    /**
     * Inverse triangular envelope type
     */
    public static int INVERSE_TRIANGULAR = 5;
    /**
     * Leading particle emission
     */
    public static int LEADING = 7;
    /**
     * Trailing particle emission
     */
    public static int TRAILING = 8;
    
    /**
     * Default 2D camera look vector (0, 0, 1)
     */
    public static final PSVector CAM2D_LOOK = new PSVector(0.0f, 0.0f, -1.0f);
    /**
     * Default 2D camera up vector (0, -1, 0)
     */
    public static final PSVector CAM2D_UP = new PSVector(0.0f, -1.0f, 0.0f);
    /**
     * Default 2D camera right vector (1, 0, 0)
     */
    public static final PSVector CAM2D_RIGHT = new PSVector(1.0f, 0.0f, 0.0f);
    /**
     * Midpoint anchor
     */
    public static int MIDPOINT = 0;
    /**
     * Corner anchor
     */
    public static int CORNER = 1;
    
}
