package pslib;
/**
 * PSEmission Interface
 * <p>The PSEmission interface extends the PSBehaviour interface to allow emission
 * behaviours to be implemented during the update() function of the GenericEmitter.
 * <p>Implementing classes may be used to facilitate per-frame modifications to
 * parameters of a GenericEmitter object.
 * <p>This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * <p>This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * <p>You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 * @author Stephen Callear
 */
public interface PSEmission extends PSBehaviour {
    /**
     * Apply the emission behaviour to the specified emitter
     * @param e emitter
     */
    public void update(GenericEmitter e);
    /**
     * Toggle the emission behaviour
     * <p>Implementing classes should disable particle emission if a false value
     * is specified.
     * @param a active toggle
     */
    public void setActive(boolean a);
}
