package pslib;

/**
 * PSTimer Class
 * <p>The PSTimer object provides timer funtionality. The object also stores the
 * delta time between updates.
 * <p>This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * <p>This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * <p>You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 * @author Stephen Callear
 */
public class PSTimer extends Object {
    private long time, call, delta;
    private boolean pause;
    /**
     * Create a new object instance
     */
    public PSTimer(){
        reset();
    }    
    /**
     * Update the timer and return the current time in milliseconds
     * @return the current time in milliseconds
     */
    public final long time(){
        update();
        return time;
    }
    /**
     * Return the time between calls to time() in milliseconds
     * @return the time between calls to time() in milliseconds
     */
    public final long delta(){
        return delta;
    }
    /**
     * Reset the timer to 0
     */
    public final void reset(){
        reset(0);
    }
    /**
     * Reset the timer to the specified value
     * @param t time in milliseconds
     */
    public final void reset(int t){
        call = System.currentTimeMillis();
        time = (long) t;
        delta = 0l;
    }
    /**
     * Pause the timer     
     * @param p boolean
     */
    public final void pause(boolean p){
        pause = p;
    }
    /**
     * Return true if the timer is paused
     * @return true if the timer is paused
     */
    public final boolean isPaused(){
        return pause;
    }
    private void update(){
        long ct = System.currentTimeMillis();
        delta = ct - call;
        call = ct;
        if(!pause) time += delta;
    }
    
}
