package pslib;
/**
 * PSVertex Class
 * <p>The PSVertex object allows a position vector, normal vector and colour to be
 * stored alongside an index value. The class implements the Comparable interface
 * to allow sorting based in index value.
 * <p>This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * <p>This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * <p>You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 * @author Stephen Callear
 */
public class PSVertex extends Object implements Comparable{
    public final PSVector position, uvcoord;
    public final PSColour colour;
    private final int index;
    /**
     * Create a new object instance with the specified values
     * @param i index
     * @param p position
     * @param c colour
     */
    public PSVertex(int i, PSVector p, PSColour c){
        this(i, p, null, c);
    }
    /**
     * Create a new object instance with the specified values
     * @param i index
     * @param p position
     * @param uv uv coordinates
     * @param c colour
     */
    public PSVertex(int i, PSVector p, PSVector uv, PSColour c){
        index = i;
        position = p;
        uvcoord = uv;
        colour = c;
    }
    /**
     * Return the index value of this object
     * @return the index value of this object
     */
    public final int index(){
        return index;
    }
    /**
     * Implementation of the Comparable interface
     * @param obj object
     * @return sort data based on index value
     */
    public final int compareTo(Object obj){
        PSVertex v = (PSVertex) obj;
        if(v.index() > index) return -1;
        else if(v.index() < index) return 1;
        else return 0;
    }
}
