package pslib;
/**
 * StaticParticle Class
 * <p>The StaticParticle object allows the storage of position, colour and size
 * particle values.
 * <p>This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * <p>This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * <p>You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see http://www.gnu.org/licenses/.
 * @author Stephen Callear
 */
public class StaticParticle extends Object {
    public final PSVector position;
    public final PSColour colour;
    public final float size, alpha;
    public final int decay;   
    /**
     * Create a new object instance with the specified values
     * @param p position
     * @param c colour
     */
    public StaticParticle(PSVector p, PSColour c){
        this(p, c, 0f, 0f, 0);
    }
    /**
     * Create a new object instance with the specified values
     * @param p position
     * @param c colour
     * @param a alpha
     */
    public StaticParticle(PSVector p, PSColour c, float a){
        this(p, c, a, 0f, 0);
    }
    /**
     * Create a new object instance with the specified values
     * @param p position
     * @param c colour
     * @param a alpha
     * @param s size
     * @param d decay
     */
    public StaticParticle(PSVector p, PSColour c, float a, float s, int d){
        position = p;
        colour = c;
        alpha = a;
        size = s;
        decay = d;
    }
    /**
     * Return a deep copy of this object
     * @return a deep copy of this object
     */
    public StaticParticle copy(){
        return new StaticParticle(position.copy(), colour.copy(), alpha, size, decay);
    }
    /**
     * Map the values of this particle upon to that specified
     * @param p particle to map values to
     */
    public final void map(DynamicParticle p){
        p.setPosition(position);
        p.setColour(colour);
        p.setAlpha(alpha);
        p.setSize(size);
        p.setDecayTime(decay);        
    }
}
